#!/bin/ksh
# Script to Create a new Zone from scratch on Solaris 10/SXCE
# Caters for whole root and sparse zones
#
# Written by Geoff Ongley, Jun 22, 2008
# geoff@unixsysadmin.net
#
# Change the sysidcfg and sed pattern if you want to use an alternate
# sysidcfg file.
# By default, this script sets autoboot to true for new zones. This
# may not be the desired behaviour.

ZONENAME=$1
PHYSNET=$2
ZONEIP=$3
ZONEDIR=/export/zones/$ZONENAME
ZONETYPE=$4
SYSIDCFG=/etc/sysidcfg
HOSTNAME=`/usr/bin/hostname`
IFCONFIG=/usr/sbin/ifconfig

#commands
ZONECFG=/usr/sbin/zonecfg
ZONEADM=/usr/sbin/zoneadm
ZLOGIN=/usr/sbin/zlogin
SED=/usr/bin/sed

export ZONENAME PHYSNET ZONEIP ZONEDIR ZONETYPE SYSIDCFG ZONECFG\
	 ZONEADM ZLOGIN SED HOSTNAME IFCONFIG 

use()
{
	echo '\nUsage: newZone.ksh <zoneName> <physicalNIC> <zoneIP> [whole | sparse]'
}

verifyPARAMS()
{
	if [ $# -lt 3 ]
	then
		echo ERROR: not enough parameters
		use
		exit 1
	fi
}

verifyZONENAME()
{
	RESULT=`cat /etc/zones/index|egrep "^${ZONENAME}\:"`
	if [[ $RESULT != "" ]]
	then
		echo ERROR: Zone exists 
		exit 1
	else
		echo INFO: Zone does not exist, OK to create
	fi

}

verifyPHYSNET()
{
	$IFCONFIG $PHYSNET > /dev/null 2>&1
	if [[ $? -gt 0 ]]
	then
		echo ERROR: Physical NIC Does Not Exist or is not plumbed
		use
		exit 1
	else
		echo INFO: Physical NIC exists, OK to use 
	fi
}

verifyZONEIP()
{
	RESULT=`echo $ZONEIP | egrep '^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$'`
	if [[ $RESULT != "" ]]
	then
		echo INFO: IP Address is probably OK 
	else
		echo ERROR: IP address $ZONEIP is not a valid IP address
		use
		exit 1
	fi
}

verifyZONETYPE()
{
	if [[ $ZONETYPE == "whole" || $ZONETYPE == "sparse" ]]
	then
		echo INFO: ZoneType is OK
	elif [[ $ZONETYPE == "" ]]
	then
		echo WARN: ZoneType was not specified, default is sparse.
		ZONETYPE=sparse
	else
		echo ERROR: ZoneType $ZONETYPE is Not Valid
		use
		exit 1
	fi
}

createZone()
{
	echo INFO: Configuring Zone...
	echo INFO: Creating a $ZONETYPE zone in $ZONEDIR
	if [[ $ZONETYPE == "whole" ]]
	then
		$ZONECFG -z $ZONENAME "create;\
       		add net;\
       		set physical=$PHYSNET;\
       		set address=$ZONEIP;\
       		end;\
       		set zonepath=$ZONEDIR;\
		remove inherit-pkg-dir dir=/usr;\
		remove inherit-pkg-dir dir=/sbin;\
		remove inherit-pkg-dir dir=/lib;\
		remove inherit-pkg-dir dir=/platform;\
		set autoboot=true"

	elif [[ $ZONETYPE == "sparse" ]]
	then	
		$ZONECFG -z $ZONENAME "create;\
		add net;\
		set physical=$PHYSNET;\
		set address=$ZONEIP;\
		end;\
		set zonepath=$ZONEDIR;\
		set autoboot=true"
	else
		echo ERROR: Total Failure...
	fi
}

installZone()
{
	$ZONEADM -z $ZONENAME install
	cat $SYSIDCFG|$SED "s/${HOSTNAME}/${ZONENAME}/g" > \
		$ZONEDIR/root/etc/sysidcfg	
	touch $ZONEDIR/root/etc/.NFS4inst_state.domain
}

postInstallZone()
{
	cp -p /opt/ADPTtools/zones/zonePost.sh ${ZONEDIR}/root/etc/init.d/
	ln ${ZONEDIR}/root/etc/init.d/zonePost.sh ${ZONEDIR}/root/etc/rc3.d/S99zonePost
	chmod 755 ${ZONEDIR}/root/etc/rc3.d/S99zonePost
}

bootZone()
{
	$ZONEADM -z $ZONENAME boot
	$ZLOGIN -C -e \# $ZONENAME
}

verifyPARAMS $@
verifyZONENAME
verifyPHYSNET 
verifyZONEIP 
verifyZONETYPE 
createZone
installZone
#postInstallZone
bootZone
